"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const allowedMediums = [
    'all',
    'braille',
    'embossed',
    'handheld',
    'print',
    'projection',
    'screen',
    'speech',
    'tty',
    'tv',
];
const allowedWarningLevels = [0, 1, 2, 3];
const allowedProfiles = [
    'none',
    'css1',
    'css2',
    'css21',
    'css3',
    'css3svg',
    'svg',
    'svgbasic',
    'svgtiny',
    'mobile',
    'atsc-tv',
    'tv',
];
function validateOptions(options) {
    if (options) {
        if (options.medium && !allowedMediums.includes(options.medium)) {
            throw new Error(`The medium must be one of the following: ${allowedMediums.join(', ')}`);
        }
        if (options.warningLevel && !allowedWarningLevels.includes(options.warningLevel)) {
            throw new Error(`The warning level must be one of the following: ${allowedWarningLevels.join(', ')}`);
        }
        if (options.timeout !== undefined && !Number.isInteger(options.timeout)) {
            throw new Error('The timeout must be an integer');
        }
        if (options.timeout && options.timeout < 0) {
            throw new Error('The timeout must be a positive integer');
        }
        if (options.profile && !allowedProfiles.includes(options.profile)) {
            throw new Error(`The profile must be one of the following: ${allowedProfiles.join(', ')}`);
        }
    }
}
exports.default = validateOptions;
